import { ApiClients, Argument, DataType } from '../types';
import { UseMutationResult } from '@tanstack/react-query';
type Client = ApiClients['shopperBaskets'];
/**
 * Mutations available for Shopper Baskets.
 * @group ShopperBaskets
 * @category Mutation
 * @enum
 */
export declare const ShopperBasketsMutations: {
    /**
      * Creates a new basket.

      The created basket is initialized with default values.
      */
    readonly CreateBasket: "createBasket";
    /**
      * Transfer the previous shopper's basket to the current shopper by updating the basket's owner. No other values change. You must obtain the shopper authorization token via SLAS and you must provide the ‘guest usid‘ in both the ‘/oauth2/login‘ and ‘/oauth2/token‘ calls while fetching the registered user JWT token.

      A success response contains the transferred basket.

      If the current shopper has an active basket, and the `overrideExisting` request parameter is `false`, then the transfer request returns a BasketTransferException (HTTP status 409). You can proceed with one of these options:
      - Keep the current shopper's active basket.
      - Merge the previous and current shoppers' baskets by calling the `baskets/merge` endpoint.
      - Force the transfer by calling the `baskets/transfer` endpoint again, with the parameter `overrideExisting=true`. Forcing the transfer deletes the current shopper's active basket.
   */
    readonly TransferBasket: "transferBasket";
    /**
     * Merge data from the previous shopper's basket into the current shopper's active basket and delete the previous shopper's basket. This endpoint doesn't merge Personally Identifiable Information (PII). You must obtain the shopper authorization token via SLAS and you must provide the ‘guest usid‘ in both the ‘/oauth2/login‘ and ‘/oauth2/token‘ calls while fetching the registered user JWT token. After the merge, all basket amounts are recalculated and totaled, including lookups for prices, taxes, shipping, and promotions.
     */
    readonly MergeBasket: "mergeBasket";
    /**
     * Removes a basket.
     */
    readonly DeleteBasket: "deleteBasket";
    /**
      * Updates a basket. Only the currency of the basket, source code, the custom
      properties of the basket, and the shipping items will be considered.
      */
    readonly UpdateBasket: "updateBasket";
    /**
     * Sets the billing address of a basket.
     */
    readonly UpdateBillingAddressForBasket: "updateBillingAddressForBasket";
    /**
     * Adds a coupon to an existing basket.
     */
    readonly AddCouponToBasket: "addCouponToBasket";
    /**
     * Removes a coupon from the basket.
     */
    readonly RemoveCouponFromBasket: "removeCouponFromBasket";
    /**
     * Sets customer information for an existing basket.
     */
    readonly UpdateCustomerForBasket: "updateCustomerForBasket";
    /**
     * Adds a gift certificate item to an existing basket.
     */
    readonly AddGiftCertificateItemToBasket: "addGiftCertificateItemToBasket";
    /**
     * Deletes a gift certificate item from an existing basket.
     */
    readonly RemoveGiftCertificateItemFromBasket: "removeGiftCertificateItemFromBasket";
    /**
     * Updates a gift certificate item of an existing basket.
     */
    readonly UpdateGiftCertificateItemInBasket: "updateGiftCertificateItemInBasket";
    /**
     * Adds new items to a basket.
     */
    readonly AddItemToBasket: "addItemToBasket";
    /**
     * Removes a product item from the basket.
     */
    readonly RemoveItemFromBasket: "removeItemFromBasket";
    /**
     * Updates an item in a basket.
     */
    readonly UpdateItemInBasket: "updateItemInBasket";
    /**
     * Updates multiple items in a basket.
     */
    readonly UpdateItemsInBasket: "updateItemsInBasket";
    /**
     * This method allows you to apply external taxation data to an existing basket to be able to pass tax rates and optional values for a specific taxable line item. This endpoint can be called only if external taxation mode was used for basket creation. See POST /baskets for more information.
     */
    readonly AddTaxesForBasketItem: "addTaxesForBasketItem";
    /**
     * Adds a payment instrument to a basket.
     */
    readonly AddPaymentInstrumentToBasket: "addPaymentInstrumentToBasket";
    /**
     * Removes a payment instrument of a basket.
     */
    readonly RemovePaymentInstrumentFromBasket: "removePaymentInstrumentFromBasket";
    /**
     * Updates payment instrument of an existing basket.
     */
    readonly UpdatePaymentInstrumentInBasket: "updatePaymentInstrumentInBasket";
    /**
     * This method allows you to put an array of priceBookIds to an existing basket, which will be used for basket calculation.
     */
    readonly AddPriceBooksToBasket: "addPriceBooksToBasket";
    /**
      * Creates a new shipment for a basket.

      The created shipment is initialized with values provided in the body
      document and can be updated with further data API calls. Considered from
      the body are the following properties if specified:

      - the ID
      - the shipping address
      - the shipping method
      - gift boolean flag
      - gift message
      - custom properties
      */
    readonly CreateShipmentForBasket: "createShipmentForBasket";
    /**
      * Removes a specified shipment and all associated product, gift certificate,
      shipping, and price adjustment line items from a basket.
      It is not allowed to remove the default shipment.
      */
    readonly RemoveShipmentFromBasket: "removeShipmentFromBasket";
    /**
      * Updates a shipment for a basket.

      The shipment is initialized with values provided in the body
      document and can be updated with further data API calls. Considered from
      the body are the following properties if specified:
      - the ID
      - the shipping address
      - the shipping method
      - gift boolean flag
      - gift message
      - custom properties
      */
    readonly UpdateShipmentForBasket: "updateShipmentForBasket";
    /**
     * Sets a shipping address of a specific shipment of a basket.
     */
    readonly UpdateShippingAddressForShipment: "updateShippingAddressForShipment";
    /**
     * Sets a shipping method to a specific shipment of a basket.
     */
    readonly UpdateShippingMethodForShipment: "updateShippingMethodForShipment";
    /**
     * This method allows you to apply external taxation data to an existing basket to be able to pass tax rates and optional values for all taxable line items. This endpoint can be called only if external taxation mode was used for basket creation. See POST /baskets for more information.
     */
    readonly AddTaxesForBasket: "addTaxesForBasket";
};
/**
 * Type for Shopper Baskets Mutation.
 * @group ShopperBaskets
 * @category Mutation
 */
export type ShopperBasketsMutation = (typeof ShopperBasketsMutations)[keyof typeof ShopperBasketsMutations];
/**
 * Mutation hook for Shopper Baskets.
 * @group ShopperBaskets
 * @category Mutation
 */
export declare function useShopperBasketsMutation<Mutation extends ShopperBasketsMutation>(mutation: Mutation): UseMutationResult<DataType<Client[Mutation]>, unknown, Argument<Client[Mutation]>>;
export {};
//# sourceMappingURL=mutation.d.ts.map