import React, { ReactElement } from 'react';
import { ShopperBasketsTypes } from 'commerce-sdk-isomorphic';
import Auth from './auth';
import { ApiClientConfigParams, ApiClients } from './hooks/types';
import { Logger } from './types';
export interface CommerceApiProviderProps extends ApiClientConfigParams {
    children: React.ReactNode;
    proxy: string;
    locale: string;
    currency: string;
    redirectURI: string;
    fetchOptions?: ShopperBasketsTypes.FetchOptions;
    headers?: Record<string, string>;
    fetchedToken?: string;
    enablePWAKitPrivateClient?: boolean;
    clientSecret?: string;
    silenceWarnings?: boolean;
    logger?: Logger;
    defaultDnt?: boolean;
    passwordlessLoginCallbackURI?: string;
    refreshTokenRegisteredCookieTTL?: number;
    refreshTokenGuestCookieTTL?: number;
}
/**
 * @internal
 */
export declare const CommerceApiContext: React.Context<ApiClients>;
/**
 * @internal
 */
export declare const ConfigContext: React.Context<Omit<CommerceApiProviderProps, "children">>;
/**
 * @internal
 */
export declare const AuthContext: React.Context<Auth>;
/**
 * Initialize a set of Commerce API clients and make it available to all of descendant components
 *
 * @group Components
 *
 * @example
 * ```js
    import {CommerceApiProvider} from '@salesforce/commerce-sdk-react'


    const App = ({children}) => {
        return (
                <CommerceApiProvider
                    clientId="12345678-1234-1234-1234-123412341234"
                    organizationId="f_ecom_aaaa_001"
                    proxy="localhost:3000/mobify/proxy/api"
                    redirectURI="localhost:3000/callback"
                    siteId="RefArch"
                    shortCode="12345678"
                    locale="en-US"
                    enablePWAKitPrivateClient={true}
                    currency="USD"
                    logger={logger}
                >
                    {children}
                </CommerceApiProvider>
        )
    }

    export default App
 * ```
 * Note: The provider can enable SLAS Private Client mode in 2 ways.
 * `enablePWAKitPrivateClient` sets commerce-sdk-react to work with the PWA proxy
 * `/mobify/slas/private` to set the private client secret. PWA users should use
 * this option.
 *
 * Non-PWA Kit users can enable private client mode by passing in a client secret
 * directly to the provider. However, be careful when doing this as you will have
 * to make sure the secret is not unexpectedly exposed to the client.
 *
 * @returns Provider to wrap your app with
 */
declare const CommerceApiProvider: (props: CommerceApiProviderProps) => ReactElement;
export default CommerceApiProvider;
//# sourceMappingURL=provider.d.ts.map